import { t, publicProcedure, router } from "./trpc";
import { z } from "zod";

export const appRouter = router({
  ping: publicProcedure.query(async () => {
    return { hello: "world" };
  }),
  org: {
    bySlug: publicProcedure
      .input(z.object({ mode: z.string() }))
      .query(async ({ input: { mode } }) => {
        if (!mode) return {mail: '', name: ''};
        const res = await fetch(
          "https://api.edu.cocorobo.cn/edu/admin/selectorganize",
          {
            method: "POST",
            body: JSON.stringify({ mode }),
            headers: {
              "Content-Type": "application/json",
            },
          }
        );
        const resJson = await res.json();
        const { mail, name } = resJson?.[0]?.[0];
        return { mail, name };
      }),
  },
  flowModel: {
    list: publicProcedure
      .input(
        z.object({
          userId: z.string(),
        })
      )
      .query(async (opts) => {
        return {
          greeting: `hello ${opts.input.userId}`,
        };
      }),
  },
  // ...
});

// Export type router type signature,
// NOT the router itself.
export type AppRouter = typeof appRouter;
